.. -*- coding: utf-8 -*-
.. :Progetto:  SoL
.. :Creato:    sab 12 lug 2014 16:55:55 CEST
.. :Autore:    Lele Gaifax <lele@metapensiero.it>
.. :Licenza:   GNU General Public License version 3 or later
..

==================================================
 :mod:`sol.printouts` -- PDF printouts generators
==================================================

.. automodule:: sol.printouts
   :members:
